@@ -23,16 +23,16 @@ from aliyunsdkimageseg.endpoint import endpoint_data
 class SegmentSkinRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'imageseg', '2019-12-30', 'SegmentSkin','imageseg')
+		RpcRequest.__init__(self, 'imageseg', '2019-12-30', 'SegmentSkin')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_URL(self):
+	def get_URL(self): # String
 		return self.get_body_params().get('URL')
 
-	def set_URL(self,URL):
-		self.add_body_params('URL', URL)
\ No newline at end of file
+	def set_URL(self, URL):  # String
+		self.add_body_params('URL', URL)
